Selection

Struct Selection 

pub struct Selection { /* private fields */ }
Simple selection theme struct

This will choose a predefined main color and background color based on the hash.

Both the main and background colors are defined as a Vec<RGB>.

Implements Theme

Implementations

Source

impl Selection

pub fn new( main: Vec<RGB>, background: Vec<RGB>, ) -> Result<Selection, ThemeError>

Generates a new Selection theme

main is used as the colors to select from for the main image color. background is used as the possible colors of the background.