pub struct Selection { /* private fields */ }Expand description
Simple selection theme struct
This will choose a predefined main color and background color based on the hash.
Both the main and background colors are defined as a Vec<RGB>.
Implements Theme
Implementations